@@ -1,3 +1,4 @@
+{-# LANGUAGE CPP #-}
 -- | Lifted version of "Control.Concurrent.STM"
 --
 -- @since 0.2.1.0
@@ -83,6 +84,11 @@ import Control.Concurrent.STM (STM, TVar, TMVar, TChan, TQueue, TBQueue)
 import qualified Control.Concurrent.STM as STM
 import Control.Monad.IO.Unlift
 import System.Mem.Weak (Weak)
+#if MIN_VERSION_base(4, 8, 0)
+import GHC.Natural (Natural)
+#else
+import Numeric.Natural (Natural)
+#endif
 
 -- | Lifted version of 'STM.atomically'
 --
@@ -165,5 +171,9 @@ newTQueueIO = liftIO STM.newTQueueIO
 -- | Lifted version of 'STM.newTBQueueIO'
 --
 -- @since 0.2.1.0
+#if MIN_VERSION_stm(2, 5, 0)
+newTBQueueIO :: MonadIO m => Natural -> m (TBQueue a)
+#else
 newTBQueueIO :: MonadIO m => Int -> m (TBQueue a)
+#endif
 newTBQueueIO = liftIO . STM.newTBQueueIO
